#
# spec file for package libvisio
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libvisio-0_1-1
Name:           libvisio
Version:        0.1.7
Release:        1.31
Summary:        Library for parsing the MS Visio file format structure
License:        MPL-2.0
Group:          Productivity/Publishing/Word
URL:            https://www.freedesktop.org/wiki/Software/libvisio
Source0:        http://dev-www.libreoffice.org/src/%{name}/%{name}-%{version}.tar.xz
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gperf
BuildRequires:  help2man
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(cppunit)
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(librevenge-0.0) >= 0.0.0
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif

%description
libvisio is a library for parsing the MS Visio file format structure. It is
cross-platform, at the moment it can be build on Microsoft Windows and Linux.

%package -n %{libname}
Summary:        Library for parsing the MS Visio file format structure
Group:          System/Libraries

%description -n %{libname}
libvisio is a library for parsing the MS Visio file format structure. It is
cross-platform, at the moment it can be build on Microsoft Windows and Linux.

%package devel
Summary:        Files for Developing with libvisio
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
libvisio is a library for parsing the MS Visio file format structure. It is
cross-platform, at the moment it can be build on Microsoft Windows and Linux.

This package contains the libvisio development files.

%package devel-doc
Summary:        Documentation for the libvisio API
Group:          Documentation/HTML
%if 0%{?suse_version} > 1200
BuildArch:      noarch
%endif

%description devel-doc
This package contains documentation for the libvisio API.

%package tools
Summary:        Tools to work with documents in MS Visio file-format
Group:          Productivity/Publishing/Word

%description tools
This package contains tools to work with documents in MS Visio file-format.

%prep
%setup -q

%build
export CXXFLAGS="%{optflags} -fvisibility-inlines-hidden"
%configure \
	--disable-werror \
	--disable-static \
	--disable-silent-rules \
	--docdir=%{_docdir}/%{name}-devel/html
make %{?_smp_mflags}

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print

mkdir -p %{buildroot}%{_mandir}/man1
for i in %{buildroot}%{_bindir}/*; do
	LD_LIBRARY_PATH=%{buildroot}%{_libdir} \
	help2man -N -o %{buildroot}%{_mandir}/man1/$(basename $i).1 $i
done

cp -p AUTHORS COPYING.* ChangeLog %{buildroot}%{_docdir}/%{name}-devel/

%fdupes -s %{buildroot}

%check
make check %{?_smp_mflags}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%{_libdir}/*.so.*

%files devel
%doc %dir %{_docdir}/%{name}-devel/
%doc %{_docdir}/%{name}-devel/[A-Z]*
%{_libdir}/*.so
%{_libdir}/pkgconfig/libvisio*.pc
%{_includedir}/libvisio-*

%files devel-doc
%doc %{_docdir}/%{name}-devel/html/

%files tools
%license COPYING.*
%doc AUTHORS ChangeLog
%{_bindir}/*
%{_mandir}/man1/*.1%{?ext_man}

%changelog
* Sun Aug 18 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.1.7:
  - Fix a few memory leaks found by oss-fuzz.
  - Fix date and time conversion to string. (tdf#98291)
  - Fix number conversion to string. (tdf#76829)
  - Fix unit conversion. (tdf#126292)
  - Handle more arrow styles. (tdf#126402)
  - Fix some issues found by Coverity.
  - Disable expanding entities by XML parser as a vulnerability
    prevention measure. Applications writing VSDX/VDX documents do not use
    entities, so there is no difference in behavior.
* Tue Nov  7 2017 tchvatal@suse.com
- Update to 0.1.6:
  * Consider stencil txtxform in binary formats (tdf#67914).
  * Parse font width scaling.
  * Remove namespace check for VDX to allow parsing documents produced by lucidchart.com (tdf#98791).
  * Output shape ID if set.
  * Fix parsing of text block background color in some cases.
  * Write bitmaps with color palette correctly.
  * Deduce text encoding from font name.
  * Parse theme fill and shadow color.
  * Parse font scheme in VSDX documents.
  * Require C++11 for build.
  * Fix various crashes, leaks and hangs when reading damaged files found by oss-fuzz.
  * Fix some issues found by Coverity.
  * Many other small improvements and fixes.
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Wed Dec 30 2015 fstrba@suse.com
- Generate manpages for the tools in libvisio-tool package
* Tue Dec 29 2015 fstrba@suse.com
- Version bump to 0.1.5
  * Rewrite text output to avoid empty spans and to make the
    function a bit more readable for common mortal (wo)man.
  * Initial emulation of line rounding property (tdf#90603).
  * Make --help output of all command line tools more
    help2man-friendly.
* Thu Dec 24 2015 fstrba@suse.com
- Version bump to 0.1.4
  * Layer properties
  * Bullets
  * Tab-sets
  * Hatch fills
  * A lot of bug-fixes
- Removed patch:
  * 0001-fix-test.patch
  - Integrated upstream
- Remove CPPFLAGS used to build with boost 1.59.0
  * Fixed upstream
* Wed Nov 11 2015 idonmez@suse.com
- Fix compilation with boost 1.59
* Fri Aug 28 2015 tchvatal@suse.com
- Version bump to 0.1.3:
  * Fix build on old compilers
- Add patch from upstream git to build with new libxml2:
  * 0001-fix-test.patch
* Fri Aug 28 2015 tchvatal@suse.com
- Version bump to 0.1.2:
  - Fix several build problems with different compilers.
  - Import more metadata properties.
  - Fix theme color import (tdf#92270).
  - Fix a bunch of crashes and hangs when reading broken documents, found
    with the help of american-fuzzy-lop.
  - Fix several memory leaks.
  - Ignore errors when parsing metadata. This makes some documents readable
    again.
  - Fix handling of character background (tdf#92271).
* Tue Jan  6 2015 tchvatal@suse.com
- Version bump 0.1.1:
  * Various bugfixes around
- Remove obsol patch:
  * libvisio-0.1.0-pkgconfig.patch
- Enable testsuite
* Fri Jul 25 2014 fstrba@suse.com
- Added patch: libvisio-0.1.0-pkgconfig.patch
  * Remove the Requires.private which breaks SLE11 builds
* Mon May 26 2014 fstrba@suse.com
- Upgrade to upstream version 0.1.0
  * ABI change
- Remove unneeded patches:
  * libvisio-0.0.30-iterator_range.patch
  * libvisio-0.0.30-wpx_seek_end.patch
- Change in dependencies:
  * Remove dependency on libwpg-devel and libwpd-devel
  * Add dependency on librevenge-devel
- License change
  * Released under MPL-2.0 only
* Sat Jan 25 2014 tchvatal@suse.com
- Cleanup with spec-cleaner and noarch the documentation.
* Sat Jan 18 2014 crrodriguez@opensuse.org
- build with -fvisibility-inlines-hidden
* Fri Nov  1 2013 tchvatal@suse.com
- Remove conditional for the doc building, use verbose build.
* Fri Jul 26 2013 fridrich.strba@suse.com
- Performance regression fix
  * Add patch to unconditionally use WPX_SEEK_END
  * Depend on libwpd-devel >= 0.9.5 that has WPX_SEEK_END
* Wed Jul 10 2013 fridrich.strba@suse.com
- Bump version to 0.0.30
  * Fix building with older boosts
  * Considerable performance improvement due to diminished
    memory consumption.
  * Implemented B-Spline conversion for xml-based formats
  * For NURBS and B-Splines where it is possible, lossless
    conversion to bezier segments.
  * Coverity fixes.
* Tue Jul  2 2013 fridrich.strba@suse.com
- Bump version to 0.0.29
  * Avoid NAN in NURBS code - fixes some freehand curves
  * Fix generation of doxygen documentation
  * Fix several parser errors due to padding zeros after chunks
* Wed Jun  5 2013 fridrich.strba@suse.com
- Bump version to 0.0.28
  * Miscellaneous crash fixes revealed by fuzzer run.
  * Miscellaneous coverity fixes.
  * New layout of source code with public headers in inc/libvisio
    directory.
* Mon Apr 22 2013 fridrich.strba@suse.com
- Bump version to 0.0.26
  * Fix missing WMFs in some Visio files
  * Use ICU for text encoding conversions
  * Honour the "HideText" property
  * Don't truncate end of the text
  * vsd2raw/vss2raw -add possibility to detect groups that are not
    properly finished and indent raw output for easier detection of
    problems
- Add dependency on libicu-devel
* Tue Feb 26 2013 fridrich.strba@suse.com
- Bump version to 0.0.25
  * don't throw from parser to the outer world
  * fix line height conversion with fixed line-height
  * fix incorrect colour conversion in documents without cached hex value
  * convert page names
  * miscellaneous coverty fixes
* Mon Dec  3 2012 fridrich.strba@suse.com
- Bump version to 0.0.23
  * Fixes fdo#48601 - wrong colours in some gradients
* Thu Nov 29 2012 fridrich.strba@suse.com
- Bump version to 0.0.22
* Wed Nov 21 2012 tchvatal@suse.com
- Disable werror explicitely. Usefull for devel but not for pkg.
* Wed Nov 21 2012 tchvatal@suse.com
- Bump version to 0.0.21
* Mon Nov  5 2012 fridrich.strba@suse.com
- Upgrade to upstream version 0.0.20
  * Support of Visio XML Drawing file-format (*.vdx)
  * Initial support of (not-yet-relesed) Visio 2013 file-formats
    (*.vsdx and *.vsdm)
  * Initial support of extracting of master shapes from Visio
    documents.
* Wed Oct 31 2012 asterios.dramis@gmail.com
- Changed license to "MPL-1.1 or GPL-2.0+ or LGPL-2.1+" (SPDX style).
- Install libvisio devel documentation in %%{_docdir}/libvisio-devel/.
- Spec file cleanup based also on spec-cleaner run.
* Mon Aug  6 2012 fridrich.strba@suse.com
- Upgrade to upstream version 0.0.19
  * Several crashes fixed
  * fix fdo#50990: import Visio documents generated by Visio SDK
  * Correct filling / closing of paths
* Fri Apr 27 2012 fridrich.strba@suse.com
- Upgrade to upstream version 0.0.16
  - OLE objects in stencils
  - More line end and start markers
  - Fix closing of NURBS
  - Regression and bug fixes.
* Tue Jan 24 2012 jengelh@medozas.de
- Remove redundant tags/sections (see specfile guidelines)
- Adjust rpm group of -tools and (main) to match libwpd
* Sat Jan 21 2012 fridrich.strba@suse.com
- Upgrade to upstream version 0.0.14
  - Embedded OLE objects
  - Text rotations
  - Rotations and flips of embedded objects
  - Regression and bug fixes.
* Fri Dec  2 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
* Fri Dec  2 2011 fridrich.strba@suse.com
- Upgrade to upstream version 0.0.9
  - Emulate infinite lines
  - Fix bug with group flips
  - Implement paragraph properties in text
  - Implement stencil text
  - Initial implementation of text fields
  - Initial implementation of line-ends
  - Fix group text z-order
- Remove unnecessary patch
- Build dependency on boost-devel
* Tue Oct  4 2011 fridrich.strba@suse.com
- Upgrade to upstream version 0.0.8
  - Fix for "dereferencing type-puned pointer will break
    strict-aliasing rules" with older compilers
  - Make order with integer types
  - Push dash array correctly to OdgGenerator
* Wed Sep 28 2011 fridrich.strba@suse.com
- libvisio-0.0.7-strictaliasing.patch: fix "dereferencing
  type-punned pointer will break strict-aliasing rules"
  with older compilers
- libvisio-0.0.7-integermess.patch: fix warning about casting
  double into integer and in the same token fix mess with integer
  widths
* Fri Sep  9 2011 fridrich.strba@suse.com
- Update to upstream version 0.0.7
  - Fix a null-pointer crash with stencil geometries
  - Improved text conversion
  - Added support for uniform b-splines
  - Fixed a problem with NURBS approximation algorithm
  - Improved handling for stencils embedded raster images
* Thu Sep  1 2011 fridrich.strba@suse.com
- Initial package of libvisio
